@@ -34,7 +34,7 @@
 GameStartDialog::GameStartDialog(size_t points, size_t player)
  : commitAction(new Lum::Model::Action()),
    points(new Lum::Model::String(Lum::Base::NumberToWString(points))),
-   player(new Lum::Model::SizeT(player)),
+   player(new Lum::Model::ULong(player)),
    success(false)
 {
   commitAction->Disable();
