@@ -33,7 +33,7 @@ class GameStartDialog : public Lum::Dlg::ActionDialog
 private:
   Lum::Model::ActionRef commitAction;
   Lum::Model::StringRef points;
-  Lum::Model::SizeTRef  player;
+  Lum::Model::ULongRef  player;
   bool                  success;
 
 public:
